@@ -82,7 +82,7 @@ static const GtkTargetEntry drag_types [] = {
 	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
 	{ NAUTILUS_ICON_DND_URL_TYPE, 0, NAUTILUS_ICON_DND_URL },
-	/* FIXME: Should handle emblems once the list view supports them */
+	{ NAUTILUS_ICON_DND_KEYWORD_TYPE, 0, NAUTILUS_ICON_DND_KEYWORD }
 };
 
 
@@ -310,21 +310,23 @@ get_drop_path (NautilusTreeViewDragDest *dest,
 		return NULL;
 	}
 
-	file = file_for_path (dest, path);
-	
-	ret = NULL;
+	ret = gtk_tree_path_copy (path);
+	file = file_for_path (dest, ret);
 
-	if (!file || !nautilus_drag_can_accept_items (file, dest->details->drag_list)){
-		if (gtk_tree_path_get_depth (path) == 1) {
+	/* Go up the tree until we find a file that can accept a drop */
+	while (file == NULL /* dummy row */ ||
+	       !nautilus_drag_can_accept_items (file, dest->details->drag_list)) {
+		if (gtk_tree_path_get_depth (ret) == 1) {
+			gtk_tree_path_free (ret);
 			ret = NULL;
+			break;
 		} else {
-			ret = gtk_tree_path_copy (path);
 			gtk_tree_path_up (ret);
-		}
-	} else {
-		ret = gtk_tree_path_copy (path);
-	}
 
+			nautilus_file_unref (file);
+			file = file_for_path (dest, ret);
+		}
+	}
 	nautilus_file_unref (file);
 	
 	return ret;
@@ -387,14 +389,14 @@ get_drop_action (NautilusTreeViewDragDest *dest,
 		return context->suggested_action;
 
 	case NAUTILUS_ICON_DND_TEXT:
-		drop_target = get_drop_target (dest, path);
+		return GDK_ACTION_COPY;
 
-		if (!drop_target) {
+	case NAUTILUS_ICON_DND_KEYWORD:
+
+		if (!path) {
 			return 0;
 		}
 
-		g_free (drop_target);
-
 		return GDK_ACTION_COPY;
 	}
 
@@ -626,6 +628,42 @@ receive_dropped_url (NautilusTreeViewDragDest *dest,
 		       x, y);
 }
 
+static void
+receive_dropped_keyword (NautilusTreeViewDragDest *dest,
+			 GdkDragContext *context,
+			 int x, int y)
+{
+	char *drop_target_uri;
+	GtkTreePath *path, *drop_path;
+	NautilusFile *drop_target_file;
+
+	gtk_tree_view_get_dest_row_at_pos (dest->details->tree_view, x, y, 
+					   &path, NULL);
+
+	drop_path = get_drop_path (dest, path);
+
+	drop_target_uri = get_drop_target (dest, drop_path);
+
+	drop_target_file = nautilus_file_get (drop_target_uri);
+
+	if (drop_target_file != NULL) {
+		nautilus_drag_file_receive_dropped_keyword (drop_target_file,
+							    (char *) dest->details->drag_data->data);
+		nautilus_file_unref (drop_target_file);
+	}
+
+
+	if (path) {
+		gtk_tree_path_free (path);
+	}
+
+	if (drop_path) {
+		gtk_tree_path_free (drop_path);
+	}
+
+	g_free (drop_target_uri);
+}
+
 static gboolean
 drag_data_received_callback (GtkWidget *widget,
 			     GdkDragContext *context,
@@ -671,6 +709,10 @@ drag_data_received_callback (GtkWidget *widget,
 			receive_dropped_text (dest, context, x, y);
 			success = TRUE;
 			break;
+		case NAUTILUS_ICON_DND_KEYWORD:
+			receive_dropped_keyword (dest, context, x, y);
+			success = TRUE;
+			break;
 		}
 
 		dest->details->drop_occurred = FALSE;
