@@ -53,7 +53,7 @@
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkenums.h>
 #include <libgnome/gnome-help.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-uidefs.h>
@@ -72,7 +72,8 @@
 #define MENU_PATH_EXTENSION_ACTIONS                     "/MenuBar/File/Extension Actions"
 #define POPUP_PATH_EXTENSION_ACTIONS                     "/background/Before Zoom Items/Extension Actions"
 
-#define COMPUTER_URI          "computer:"
+#define NETWORK_URI          "network:"
+#define COMPUTER_URI         "computer:"
 #define BURN_CD_URI          "burn:"
 
 /* Struct that stores all the info necessary to activate a bookmark. */
@@ -181,12 +182,10 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 				 _("Go to the location specified by this bookmark"),
 				 NULL);
 	
-	/* TODO: This should really use themed icons and
-	   nautilus_bookmark_get_icon (bookmark), but that doesn't work yet*/
 	g_object_set_data_full (G_OBJECT (action), "menu-icon",
 				g_object_ref (pixbuf),
 				g_object_unref);
-	
+
 	g_signal_connect_data (action, "activate",
 			       G_CALLBACK (activate_bookmark_in_menu_item),
 			       bookmark_holder, 
@@ -279,6 +278,14 @@ action_go_to_computer_callback (GtkAction *action,
 			       COMPUTER_URI);
 }
 
+static void
+action_go_to_network_callback (GtkAction *action, 
+				gpointer user_data) 
+{
+	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
+			       NETWORK_URI);
+}
+
 static void
 action_go_to_templates_callback (GtkAction *action,
 				 gpointer user_data) 
@@ -371,7 +378,6 @@ static void
 action_about_nautilus_callback (GtkAction *action,
 				gpointer user_data)
 {
-	static GtkWidget *about = NULL;
 	const gchar *authors[] = {
 		"Alexander Larsson",
 		"Ali Abdin",
@@ -414,69 +420,57 @@ action_about_nautilus_callback (GtkAction *action,
 		NULL
 	};
 	const gchar *license[] = {
-		N_("Nautilus is free software; you can redistribute it and/or modify \n"
-		   "it under the terms of the GNU General Public License as published by \n"
-		   "the Free Software Foundation; either version 2 of the License, or \n"
+		N_("Nautilus is free software; you can redistribute it and/or modify "
+		   "it under the terms of the GNU General Public License as published by "
+		   "the Free Software Foundation; either version 2 of the License, or "
 		   "(at your option) any later version."),
-		N_("Nautilus is distributed in the hope that it will be useful, \n"
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+		N_("Nautilus is distributed in the hope that it will be useful, "
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
 		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License \n"
-		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., \n"
+		N_("You should have received a copy of the GNU General Public License "
+		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., "
 		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
 	};
 	gchar *license_trans;
-	char *logo_path;
-	GdkPixbuf *logo;
+	gchar *logo_path;
+	GdkPixbuf *logo = NULL;
 
-	if (about == NULL) {
- 
-		about = gtk_about_dialog_new ();
+	license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
+					     _(license[2]), NULL);
 
-		license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
-					     _(license[2]), "\n\n", NULL);
-
-		/* Translators should localize the following string
-		 * which will be displayed at the bottom of the about
-		 * box to give credit to the translator(s).
-		 */
-
-		logo_path = nautilus_pixmap_file ("nautilus-launch-icon.png");
-		logo = NULL;
-		if (logo_path != NULL) {
-			logo = gdk_pixbuf_new_from_file (logo_path, NULL);
-		}
-		
-		g_object_set (about,
-			      "name", _("Nautilus"),
-			      "version", VERSION,
-			      "comments", _("Nautilus is a graphical shell "
-					   "for GNOME that makes it "
-					   "easy to manage your files "
-					   "and the rest of your system."),
-			      "copyright", _("Copyright \xC2\xA9 1999-2005 "
-					     "The Nautilus authors"),
-			      "license", license_trans,
-			      "authors", authors,
-			      "documenters", documenters,
+	logo_path = nautilus_pixmap_file ("nautilus-launch-icon.png");
+	if (logo_path != NULL) {
+		logo = gdk_pixbuf_new_from_file (logo_path, NULL);
+	}
+	
+	gtk_show_about_dialog (GTK_WINDOW (user_data),
+			       "name", _("Nautilus"),
+			       "version", VERSION,
+			       "comments", _("Nautilus is a graphical shell "
+					     "for GNOME that makes it "
+					     "easy to manage your files "
+					     "and the rest of your system."),
+			       "copyright", _("Copyright \xC2\xA9 1999-2006 "
+					      "The Nautilus authors"),
+			       "license", license_trans,
+			       "wrap-license", TRUE,
+			       "authors", authors,
+			       "documenters", documenters,
+				/* Translators should localize the following string
+				 * which will be displayed at the bottom of the about
+				 * box to give credit to the translator(s).
+				 */
 			      "translator-credits", _("translator-credits"),
 			      "logo", logo,
 			      NULL);
-		
-		if (logo != NULL) {
-			g_object_unref (logo);
-		}		
 
-		g_free (license_trans);
-		g_free (logo_path);
-
-		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (user_data));
-
-		eel_add_weak_pointer (&about);
+	if (logo != NULL) {
+		g_object_unref (logo);
 	}
-	
-	gtk_window_present (GTK_WINDOW (about));
+
+	g_free (license_trans);
+	g_free (logo_path);
 }
 
 static void
@@ -677,6 +671,10 @@ static const GtkActionEntry main_entries[] = {
     N_("_Computer"), NULL,           /* label, accelerator */
     N_("Go to the computer location"),                                  /* tooltip */ 
     G_CALLBACK (action_go_to_computer_callback) },
+  { "Go to Network", "gnome-fs-network",                        /* name, stock id */
+    N_("_Network"), NULL,           /* label, accelerator */
+    N_("Go to the network location"),                                  /* tooltip */ 
+    G_CALLBACK (action_go_to_network_callback) },
   { "Go to Templates", "stock_new-template",                        /* name, stock id */
     N_("T_emplates"), NULL,           /* label, accelerator */
     N_("Go to the templates folder"),                                  /* tooltip */ 
@@ -731,14 +729,25 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 	ui = nautilus_ui_string_get ("nautilus-shell-ui.xml");
 	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
-	if (!have_burn_uri ()) {
-		action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_GO_TO_BURN_CD);
-		gtk_action_set_visible (action, FALSE);
-	}
-
 	nautilus_window_initialize_bookmarks_menu (window);
 }
 
+void
+nautilus_window_initialize_menus_constructed (NautilusWindow *window)
+{
+	GtkAction *action;
+
+	/* Don't call have_burn_uri() for the desktop window, as this is a very
+	 * expensive operation during login (around 1 second) ---
+	 * have_burn_uri() has to create a "burn:///" URI, which causes
+	 * gnome-vfs to link in libmapping.so from nautilus-cd-burner.
+	 */
+	if (nautilus_window_has_menubar_and_statusbar (window) && !have_burn_uri ()) {
+		action = gtk_action_group_get_action (window->details->main_action_group, NAUTILUS_ACTION_GO_TO_BURN_CD);
+ 		gtk_action_set_visible (action, FALSE);
+ 	}
+}
+
 static GList *
 get_extension_menus (NautilusWindow *window)
 {
